---
name: Feature request
about: Suggest an idea for enhancing RAGNARDoc
title: ""
labels: enhancement
assignees: ""
---

### Requested feature

<!-- Describe the feature you have in mind and the user need it addresses. -->

...

### Alternatives

<!-- Describe any alternatives you have considered. -->

...

<!-- ⚠️ ATTENTION: When sharing screenshots, attachments, or other data make sure not to include any sensitive information. -->
